@@ -3,10 +3,6 @@ import os
 import threading
 from typing import List
 
-import requests
-from requests.adapters import HTTPAdapter
-from urllib3 import Retry
-
 from maitai._config_listener_thread import ConfigListenerThread
 from maitai._maitai_client import MaitaiClient
 from maitai.models.application import Application
@@ -17,22 +13,12 @@ from maitai_common.config import config_service
 
 class Config(MaitaiClient):
 
-    maitai_ws = os.environ.get(
-        "MAITAI_WS", "wss://09hidyy627.execute-api.us-west-2.amazonaws.com/production"
-    )
+    maitai_ws = "wss://09hidyy627.execute-api.us-west-2.amazonaws.com/production"
     config_dir = os.path.expanduser(os.environ.get("MAITAI_CONFIG_DIR", "~/.maitai"))
     refresh_timer = None
 
     def __init__(self):
-        retry_strategy = Retry(total=3, backoff_factor=1)
-        adapter = HTTPAdapter(max_retries=retry_strategy)
-
-        self._session = requests.Session()
-        self._session.mount("http://", adapter)
-        self._session.mount("https://", adapter)
-
         self._api_key = None
-        self._applications: dict[str, Application] = {}
         self._company_id = None
         self.websocket_listener_thread = None
         self.config_listener_thread = None
@@ -43,8 +29,9 @@ class Config(MaitaiClient):
             groq_api_key=Key(id=-1, key_value=os.environ.get("GROQ_API_KEY")),
             anthropic_api_key=Key(id=-1, key_value=os.environ.get("ANTHROPIC_API_KEY")),
             cerebras_api_key=Key(id=-1, key_value=os.environ.get("CEREBRAS_API_KEY")),
+            sambanova_api_key=Key(id=-1, key_value=os.environ.get("SAMBANOVA_API_KEY")),
         )
-        self.refresh_interval = 30 * 60  # 1 hour in seconds
+        self.refresh_interval = 30 * 60  # 30 minutes in seconds
 
     @property
     def api_key(self):
@@ -66,7 +53,20 @@ class Config(MaitaiClient):
     def api_key(self, value):
         self._api_key = value
 
-    def initialize(self, api_key, retry=0, use_async=False):
+    def refresh_applications(self):
+        response_json = self.init_sdk(self.api_key, self.maitai_host)
+
+        applications = [
+            Application.model_validate(app_json)
+            for app_json in response_json["applications"]
+        ]
+        self._company_id = response_json.get("company_id")
+        if not self._company_id:
+            raise Exception("Company ID not found in response")
+
+        self.store_application_metadata(applications)
+
+    def initialize(self, api_key, retry=0):
         if self.initialized and self.api_key == api_key:
             return
 
@@ -77,56 +77,43 @@ class Config(MaitaiClient):
         self.initialized = True
         try:
             # Call init_sdk and process the response
-            response_json = self.init_sdk(
-                api_key, self.maitai_host, use_async=use_async
-            )
-
-            applications = [
-                Application.model_validate(app_json)
-                for app_json in response_json["applications"]
-            ]
-            self._company_id = response_json.get("company_id")
-            if not self._company_id:
-                raise Exception("Company ID not found in response")
-
-            self.store_application_metadata(applications)
+            self.refresh_applications()
             self._initialize_websocket()
-            self._start_refresh_timer(use_async=use_async)
+            self._start_refresh_timer()
         except Exception as e:
             self.cleanup()  # Ensure cleanup on failure
             try:
                 self._load_config_from_file()
             except Exception:
-                raise e
+                raise e from None
             self.initialized = False
             if retry < 5:
-                t = threading.Timer(
+                if self.refresh_timer:
+                    self.refresh_timer.cancel()
+                self.refresh_timer = threading.Timer(
                     interval=2**retry,
                     function=self.initialize,
-                    args=(api_key, retry + 1, use_async),
+                    args=(api_key, retry + 1),
                 )
-                t.daemon = True
-                t.start()
+                self.refresh_timer.daemon = True
+                self.refresh_timer.start()
 
-    def _start_refresh_timer(self, use_async=False):
+    def _start_refresh_timer(self):
         if self.refresh_timer:
             self.refresh_timer.cancel()
         self.refresh_timer = threading.Timer(
-            self.refresh_interval, self._refresh_and_reschedule, args=(use_async,)
+            self.refresh_interval, self._refresh_and_reschedule
         )
         self.refresh_timer.daemon = True
         self.refresh_timer.start()
 
-    def _refresh_and_reschedule(self, use_async=False):
+    def _refresh_and_reschedule(self):
         try:
-            self.refresh_applications(use_async=use_async)
+            self.refresh_applications()
         except Exception as e:
             pass
         finally:
-            self._start_refresh_timer(use_async=use_async)
-
-    def get_application(self, application_ref_name: str) -> Application:
-        return self._applications.get(application_ref_name)
+            self._start_refresh_timer()
 
     def get_application_action_config(
         self, application_ref_name: str, action_type: str
@@ -137,7 +124,6 @@ class Config(MaitaiClient):
 
     def store_application_metadata(self, applications: List[Application]):
         for application in applications:
-            self._applications[application.application_ref_name] = application
             for action_type in application.action_types:
                 if (
                     application.application_ref_name
@@ -184,11 +170,18 @@ class Config(MaitaiClient):
     def cleanup(self):
         if self.config_listener_thread:
             self.config_listener_thread.terminate()
+            try:
+                self.config_listener_thread.join(
+                    timeout=1.0
+                )  # Give thread time to cleanup
+            except Exception:
+                pass  # If join fails, continue with cleanup
             self.config_listener_thread = None
+
         if self.refresh_timer:
             self.refresh_timer.cancel()
             self.refresh_timer = None
-        self.initialized = False  # Reset initialization state
+        self.initialized = False
 
 
 config = Config()
