@@ -12,12 +12,7 @@ import openai.types.chat as openai_chat_types
 
 from maitai._config import config
 from maitai._evaluator import Evaluator
-from maitai._inference import (
-    Inference,
-    InferenceException,
-    InferenceWarning,
-    MaitaiConnectionError,
-)
+from maitai._inference import Inference
 from maitai._types import (
     Body,
     EvaluateCallback,
@@ -35,6 +30,11 @@ from maitai._utils import (
     required_args,
     type_to_response_format_param,
 )
+from maitai.exceptions import (
+    InferenceException,
+    InferenceWarning,
+    MaitaiConnectionError,
+)
 from maitai.models.chat import (
     AzureParams,
     ChatCompletionParams,
@@ -43,6 +43,7 @@ from maitai.models.chat import (
 )
 from maitai.models.config import InferenceLocations
 from maitai.models.inference import InferenceStreamResponse
+from maitai.models.key import Key
 from maitai.models.metric import RequestTimingMetric
 from maitai.tools import Tools
 
@@ -71,13 +72,13 @@ class MaitaiAsync:
         max_retries: int = DEFAULT_MAX_RETRIES,
         default_headers: Optional[Mapping[str, str]] = None,
         default_query: Optional[Mapping[str, object]] = None,
-        http_client: Optional[httpx.Client] = None,
+        http_client: Optional[httpx.AsyncClient] = None,
         _strict_response_validation: bool = False,
     ):
         if not maitai_api_key:
             maitai_api_key = os.environ.get("MAITAI_API_KEY")
         if maitai_api_key:
-            config.initialize(maitai_api_key, use_async=True)
+            config.initialize(maitai_api_key)
         else:
             raise ValueError(
                 "MAITAI_API_KEY has not been set. Either set via environment variable or pass it directly into the client."
@@ -87,17 +88,42 @@ class MaitaiAsync:
                 "api_key is deprecated. Use provider specific keys instead. Supported variables: openai_api_key, groq_api_key, anthropic_api_key, cerebras_api_key, azure_api_key, sambanova_api_key"
             )
         if openai_api_key:
-            config.auth_keys.openai_api_key.key_value = openai_api_key
+            if not config.auth_keys.openai_api_key:
+                config.auth_keys.openai_api_key = Key(
+                    key_value=openai_api_key,
+                )
+            else:
+                config.auth_keys.openai_api_key.key_value = openai_api_key
         if groq_api_key:
-            config.auth_keys.groq_api_key.key_value = groq_api_key
+            if not config.auth_keys.groq_api_key:
+                config.auth_keys.groq_api_key = Key(
+                    key_value=groq_api_key,
+                )
+            else:
+                config.auth_keys.groq_api_key.key_value = groq_api_key
         if anthropic_api_key:
             config.auth_keys.anthropic_api_key.key_value = anthropic_api_key
         if cerebras_api_key:
-            config.auth_keys.cerebras_api_key.key_value = cerebras_api_key
+            if not config.auth_keys.cerebras_api_key:
+                config.auth_keys.cerebras_api_key = Key(
+                    key_value=cerebras_api_key,
+                )
+            else:
+                config.auth_keys.cerebras_api_key.key_value = cerebras_api_key
         if azure_api_key:
-            config.auth_keys.azure_api_key.key_value = azure_api_key
+            if not config.auth_keys.azure_api_key:
+                config.auth_keys.azure_api_key = Key(
+                    key_value=azure_api_key,
+                )
+            else:
+                config.auth_keys.azure_api_key.key_value = azure_api_key
         if sambanova_api_key:
-            config.auth_keys.sambanova_api_key.key_value = sambanova_api_key
+            if not config.auth_keys.sambanova_api_key:
+                config.auth_keys.sambanova_api_key = Key(
+                    key_value=sambanova_api_key,
+                )
+            else:
+                config.auth_keys.sambanova_api_key.key_value = sambanova_api_key
         self._client = None
         if azure_api_key:
             azure_params = AzureParams(
