@@ -1,4 +1,9 @@
-from maitai.models.config import Config, InferenceLocations
+import os
+
+if os.environ.get("MAITAI_ENV") in ["prod", "staging", "development"]:
+    from maitai_models.config import Config, InferenceLocations
+else:
+    from maitai.models.config import Config, InferenceLocations
 
 
 def get_default_config() -> Config:
